A library to make it as easy as possible to render Django using React, all server side. The browser then hydrates seamlessly, allowing you to add dynamic behavior. Best of both worlds.

Currently very much undocumented but used in production just fine. Interested in setting it up? Email me. You can find my info in my GitHub profile.
